@@ -1,11 +1,11 @@
-from commmons import html
+from commmons import html_from_url
 
 from vripper.model.vimage import VImage
 from vripper.model.vthread import VThread
 
 
 def thm_init(url):
-    root = html.from_url(url)
+    root = html_from_url(url)
 
     thread = VThread(
         id=root.xpath("//article[contains(@class, 'post')]")[0].attrib["id"],
