@@ -2,7 +2,7 @@ import urllib.parse as urlparse
 import xml.etree.ElementTree as ET
 
 import requests
-from commmons import get_query_param, strip_query_params
+from commmons import breakdown, get_query_params
 
 from vripper.model.vimage import VImage
 from vripper.model.vpost import VPost
@@ -28,7 +28,7 @@ def vg_get_xml(url):
     thread.id = url.split('/')[-1].split('-')[0]
 
     params = {"t": thread.id}
-    postid = get_query_param(url, "p")
+    postid = get_query_params(url).get("p")
     if postid:
         params = {"p": postid}
 
@@ -40,8 +40,8 @@ def vg_get_xml(url):
 
     t = root.find("thread")
     thread.title = t.attrib["title"]
-    thread.url = strip_query_params(url)
-    reply_index = get_query_param(url, "r")
+    thread.url, query_params = breakdown(url)
+    reply_index = query_params.get("r")
     if reply_index:
         thread.id += f"-r{reply_index}"
         thread.title += f" Reply {reply_index}"
